@@ -19,7 +19,7 @@
 #' landscape_classes <- classify_habitats(raster = landscape, classes = 5)
 #' landscape_random <- randomize_raster(raster = landscape_classes, n_random = 19)
 #'
-#' plot_randomized_raster(landscape_random, col = col)
+#' plot_randomized_raster(landscape_random)
 #'
 #' palette <- viridis::viridis(n = 5)
 #' plot_randomized_raster(landscape_random, n = 5, col = palette, nrow = 3, ncol = 2)
@@ -37,11 +37,13 @@ plot_randomized_raster <- function(raster,
 
   # check if class is correct
   if (class(raster) != "rd_ras") {
+
     stop("Class of 'raster' must be 'rd_ras'.", call. = FALSE)
   }
 
   # check if observed is present
-  if (!"observed" %in% names(raster)) {
+  if (!methods::is(raster$observed, "RasterLayer")) {
+
     stop("Input must include 'observed' raster.", call. = FALSE)
   }
 
@@ -49,7 +51,9 @@ plot_randomized_raster <- function(raster,
 
   # print warning if more than 10 classes are present
   if (verbose) {
+
     if (length(habitats) > 10) {
+
       warning("The raster has more than 10 classes. Please make sure discrete classes are provided.",
               call. = FALSE)
     }
@@ -59,13 +63,14 @@ plot_randomized_raster <- function(raster,
   if (is.null(n)) {
 
     # check if less than 3 randomized raster are present
-    if (length(raster) < 4) {
+    if (length(raster$randomized) < 4) {
 
       # set n to numer of randomized raster
-      n <- length(raster) - 1
+      n <- length(raster$randomized)
 
       # print message
       if (verbose) {
+
         message("> Setting n = ", n)
       }
     }
@@ -78,6 +83,7 @@ plot_randomized_raster <- function(raster,
 
       # print message
       if (verbose) {
+
         message("> Setting n = ", n)
       }
     }
@@ -87,49 +93,54 @@ plot_randomized_raster <- function(raster,
   if (length(n) > 1) {
 
     # check if any ID is larger than length of list
-    if (any(n > length(raster))) {
+    if (any(n > length(raster$randomized))) {
 
       # remove not valid IDs
-      n <- n[n < length(raster)]
+      n <- n[n <= length(raster$randomized)]
 
       if (length(n) == 0) {
+
         stop("Please provide at least on valid ID for n.", call. = FALSE)
       }
 
       if (verbose) {
+
         warning("Using only n IDs that are present in randomized data.", call. = FALSE)
       }
 
     }
 
-    subset_raster <- raster[n]
+    subset_raster <- raster$randomized[n]
   }
 
   # only one number provided for n
   else {
 
     # n larger than number of randomized rasters
-    if (n > length(raster) - 1) {
+    if (n > length(raster$randomized)) {
 
       # check if less than 3 randomized raster present
-      if (length(raster) < 4) {
-        n <- length(raster) - 1
+      if (length(raster$randomized) < 4) {
+
+        n <- length(raster$randomized)
       }
 
       # more than 3 randomized raster
       else{
+
         n <- 3
       }
 
       # print warning
       if (verbose) {
+
         warning("'n' larger than number of randomized rasters - setting n = ", n, ".",
                 call. = FALSE)
       }
     }
 
     # sample raster
-    subset_raster <- sample(x = raster[names(raster) != "observed"], size = n)
+    subset_raster <- sample(x = raster$randomized, size = n)
   }
 
   # add observed raster to subset
